==> haskell-dec-0.0.3-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dec
version:              0.0.3
visibility:           public
id:                   dec-0.0.3-FO6fyD2XpRyARvxKWGtzdG
key:                  dec-0.0.3-FO6fyD2XpRyARvxKWGtzdG
license:              BSD-3-Clause
copyright:            (c) 2019 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/vec
synopsis:             Decidable propositions.
description:
    This package provides a @Dec@ type.

    @
    type Not a = a -> Void

    data Dec a
    \    = Yes a
    \    | No (Not a)
    @

category:             Data, Dependent Types
abi:                  61b9fd5005c542d9583a5aec3f2c4ae3
exposed:              True
exposed-modules:      Data.Type.Dec
import-dirs:          /usr/lib/ghc-8.8.3/site-local/dec-0.0.3
library-dirs:         /usr/lib/ghc-8.8.3/site-local/dec-0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/dec-0.0.3
hs-libraries:         HSdec-0.0.3-FO6fyD2XpRyARvxKWGtzdG
depends:              base-4.13.0.0
haddock-interfaces:   /usr/share/doc/haskell-dec/html/dec.haddock
haddock-html:         /usr/share/doc/haskell-dec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dec-0.0.3-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dec
version:              0.0.3
visibility:           public
id:                   dec-0.0.3-7CFwysk0LzzFClMA9Y5GYj
key:                  dec-0.0.3-7CFwysk0LzzFClMA9Y5GYj
license:              BSD-3-Clause
copyright:            (c) 2019 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/vec
synopsis:             Decidable propositions.
description:
    This package provides a @Dec@ type.

    @
    type Not a = a -> Void

    data Dec a
    \    = Yes a
    \    | No (Not a)
    @

category:             Data, Dependent Types
abi:                  280ba38bd84cd6f695256ae8375c6970
exposed:              True
exposed-modules:      Data.Type.Dec
import-dirs:          /usr/lib/ghc-8.10.1/site-local/dec-0.0.3
library-dirs:         /usr/lib/ghc-8.10.1/site-local/dec-0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/dec-0.0.3
hs-libraries:         HSdec-0.0.3-7CFwysk0LzzFClMA9Y5GYj
depends:              base-4.14.0.0
haddock-interfaces:   /usr/share/doc/haskell-dec/html/dec.haddock
haddock-html:         /usr/share/doc/haskell-dec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
